@@ -12,6 +12,7 @@
 #define XH_X2H_FILTER_MATCHED       8
 #define XH_X2H_ROOT_FOUND           16
 #define XH_X2H_IS_NOT_BLANK         32
+#define XH_X2H_DOCTYPE_FOUND        64
 
 #define XH_X2H_NEED_NORMALIZE       (XH_X2H_NORMALIZE_REF |             \
                                      XH_X2H_NORMALIZE_LINE_FEED)
@@ -35,6 +36,45 @@
     XH_X2H_PROCESS_STATE(END_CDATA1_START)                              \
     XH_X2H_PROCESS_STATE(END_CDATA2_START)                              \
     XH_X2H_PROCESS_STATE(END_CDATA3_START)                              \
+    XH_X2H_PROCESS_STATE(DOCTYPE_1_1_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_1_2_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_1_3_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_2_1_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_2_2_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_2_3_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_NAME_START)                            \
+    XH_X2H_PROCESS_STATE(DOCTYPE_NAME_START_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_NAME_END_START)                        \
+    XH_X2H_PROCESS_STATE(DOCTYPE_NAME_BLANK_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_1_1_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_1_2_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_1_3_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_2_1_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_2_2_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_LOCATION_DOCTYPE_DELIM_START)   \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_LOCATION_DOCTYPE_DELIM_SKIP_BLANK_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_1_END_OF_LITERAL_START)         \
+    XH_X2H_PROCESS_STATE(DOCTYPE_SYSTEM_2_END_OF_LITERAL_START)         \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_1_1_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_1_2_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_1_3_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_2_1_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_2_2_START)                      \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_ID_DOCTYPE_DELIM_START)         \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_ID_DOCTYPE_DELIM_SKIP_BLANK_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_1_DOCTYPE_DELIM_START) \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_1_DOCTYPE_DELIM_SKIP_BLANK_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_1_1_END_OF_LITERAL_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_1_2_END_OF_LITERAL_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_2_DOCTYPE_DELIM_START) \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_2_DOCTYPE_DELIM_SKIP_BLANK_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_2_1_END_OF_LITERAL_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_LOCATION_2_2_END_OF_LITERAL_START)\
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_1_END_OF_LITERAL_START)         \
+    XH_X2H_PROCESS_STATE(DOCTYPE_PUBLIC_2_END_OF_LITERAL_START)         \
+    XH_X2H_PROCESS_STATE(DOCTYPE_END_START)                             \
+    XH_X2H_PROCESS_STATE(DOCTYPE_INTSUBSET_START)                       \
+    XH_X2H_PROCESS_STATE(DOCTYPE_INTSUBSET_START_START)                 \
     XH_X2H_PROCESS_STATE(CDATA_WITH_TRIM_1_1_START)                     \
     XH_X2H_PROCESS_STATE(CDATA_WITH_TRIM_1_2_START)                     \
     XH_X2H_PROCESS_STATE(CDATA_WITH_TRIM_1_3_START)                     \
